@@ -1,31 +1,37 @@
 /****************************************************************************
  **
- ** Copyright (C) 2015 The Qt Company Ltd.
- ** Contact: http://www.qt.io/licensing/
+ ** Copyright (C) 2016 The Qt Company Ltd.
+ ** Contact: https://www.qt.io/licensing/
  **
  ** This file is part of the QtBluetooth module of the Qt Toolkit.
  **
- ** $QT_BEGIN_LICENSE:LGPL21$
+ ** $QT_BEGIN_LICENSE:LGPL$
  ** Commercial License Usage
  ** Licensees holding valid commercial Qt licenses may use this file in
  ** accordance with the commercial license agreement provided with the
  ** Software or, alternatively, in accordance with the terms contained in
  ** a written agreement between you and The Qt Company. For licensing terms
- ** and conditions see http://www.qt.io/terms-conditions. For further
- ** information use the contact form at http://www.qt.io/contact-us.
+ ** and conditions see https://www.qt.io/terms-conditions. For further
+ ** information use the contact form at https://www.qt.io/contact-us.
  **
  ** GNU Lesser General Public License Usage
  ** Alternatively, this file may be used under the terms of the GNU Lesser
- ** General Public License version 2.1 or version 3 as published by the Free
- ** Software Foundation and appearing in the file LICENSE.LGPLv21 and
- ** LICENSE.LGPLv3 included in the packaging of this file. Please review the
- ** following information to ensure the GNU Lesser General Public License
- ** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
- ** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+ ** General Public License version 3 as published by the Free Software
+ ** Foundation and appearing in the file LICENSE.LGPL3 included in the
+ ** packaging of this file. Please review the following information to
+ ** ensure the GNU Lesser General Public License version 3 requirements
+ ** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
  **
- ** As a special exception, The Qt Company gives you certain additional
- ** rights. These rights are described in The Qt Company LGPL Exception
- ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+ ** GNU General Public License Usage
+ ** Alternatively, this file may be used under the terms of the GNU
+ ** General Public License version 2.0 or (at your option) the GNU General
+ ** Public license version 3 or any later version approved by the KDE Free
+ ** Qt Foundation. The licenses are as published by the Free Software
+ ** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+ ** included in the packaging of this file. Please review the following
+ ** information to ensure the GNU General Public License requirements will
+ ** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+ ** https://www.gnu.org/licenses/gpl-3.0.html.
  **
  ** $QT_END_LICENSE$
  **
@@ -33,7 +39,6 @@
 
 package org.qtproject.qt5.android.bluetooth;
 
-import android.app.Activity;
 import android.bluetooth.BluetoothAdapter;
 import android.bluetooth.BluetoothDevice;
 import android.bluetooth.BluetoothGatt;
@@ -42,6 +47,7 @@ import android.bluetooth.BluetoothGattCharacteristic;
 import android.bluetooth.BluetoothGattDescriptor;
 import android.bluetooth.BluetoothGattService;
 import android.bluetooth.BluetoothProfile;
+import android.content.Context;
 import android.util.Log;
 
 import java.util.ArrayList;
@@ -64,16 +70,16 @@ public class QtBluetoothLE {
     @SuppressWarnings({"CanBeFinal", "WeakerAccess"})
     long qtObject = 0;
     @SuppressWarnings("WeakerAccess")
-    Activity qtactivity = null;
+    Context qtContext = null;
 
     @SuppressWarnings("WeakerAccess")
     public QtBluetoothLE() {
         mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
     }
 
-    public QtBluetoothLE(final String remoteAddress, Activity activity) {
+    public QtBluetoothLE(final String remoteAddress, Context context) {
         this();
-        qtactivity = activity;
+        qtContext = context;
         mRemoteGattAddress = remoteAddress;
     }
 
@@ -407,7 +413,7 @@ public class QtBluetoothLE {
             return false;
         }
 
-        mBluetoothGatt = mRemoteGattDevice.connectGatt(qtactivity, false, gattCallback);
+        mBluetoothGatt = mRemoteGattDevice.connectGatt(qtContext, false, gattCallback);
         return mBluetoothGatt != null;
     }
 
@@ -829,11 +835,13 @@ public class QtBluetoothLE {
         newJob.jobType = IoJobType.Write;
 
         // writeMode must be in sync with QLowEnergyService::WriteMode
-        // For now we ignore SignedWriteType as Qt doesn't support it yet.
         switch (writeMode) {
             case 1: //WriteWithoutResponse
                 newJob.requestedWriteType = BluetoothGattCharacteristic.WRITE_TYPE_NO_RESPONSE;
                 break;
+            case 2: //WriteSigned
+                newJob.requestedWriteType = BluetoothGattCharacteristic.WRITE_TYPE_SIGNED;
+                    break;
             default:
                 newJob.requestedWriteType = BluetoothGattCharacteristic.WRITE_TYPE_DEFAULT;
                 break;
