@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtNfc module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -36,6 +42,8 @@
 #include <QtCore/QMap>
 #include <QtCore/QRegExp>
 
+#include <QtCore/qglobalstatic.h>
+
 QT_BEGIN_NAMESPACE
 
 /*!
@@ -167,7 +175,8 @@ QT_BEGIN_NAMESPACE
     This macro should be expanded in the implementation file for \a className.
 */
 
-static QMap<QString, const QMetaObject *> registeredNdefRecordTypes;
+typedef QMap<QString, const QMetaObject *> NDefRecordTypesMap;
+Q_GLOBAL_STATIC(NDefRecordTypesMap, registeredNdefRecordTypes)
 
 class QQmlNdefRecordPrivate
 {
@@ -196,7 +205,7 @@ void qRegisterNdefRecordTypeHelper(const QMetaObject *metaObject,
                                    QNdefRecord::TypeNameFormat typeNameFormat,
                                    const QByteArray &type)
 {
-    registeredNdefRecordTypes.insert(urnForRecordType(typeNameFormat, type), metaObject);
+    registeredNdefRecordTypes()->insert(urnForRecordType(typeNameFormat, type), metaObject);
 }
 
 /*!
@@ -206,7 +215,7 @@ QQmlNdefRecord *qNewDeclarativeNdefRecordForNdefRecord(const QNdefRecord &record
 {
     const QString urn = urnForRecordType(record.typeNameFormat(), record.type());
 
-    QMapIterator<QString, const QMetaObject *> i(registeredNdefRecordTypes);
+    QMapIterator<QString, const QMetaObject *> i(*registeredNdefRecordTypes());
     while (i.hasNext()) {
         i.next();
 
@@ -243,6 +252,14 @@ QQmlNdefRecord::QQmlNdefRecord(const QNdefRecord &record, QObject *parent)
     d_ptr->record = record;
 }
 
+/*!
+    Destroys the QQmlNdefRecord instance.
+*/
+QQmlNdefRecord::~QQmlNdefRecord()
+{
+    delete d_ptr;
+}
+
 /*!
     \enum QQmlNdefRecord::TypeNameFormat
 
@@ -271,7 +288,7 @@ QString QQmlNdefRecord::type() const
 }
 
 /*!
-    Sets the record type to \a type if it is not currently equal to \a type; otherwise does
+    Sets the record type to \a newtype if it is not currently equal to \l type(); otherwise does
     nothing.  If the record type is set the typeChanged() signal will be emitted.
 
     \sa QNdefRecord::setType(), QNdefRecord::type()
